# @summary Manages the configuration for Octominer.
#
class octominer::config {
  $root_dir      = $octominer::root_dir
  $octo_ping     = $octominer::octo_ping
  $octo_command  = $octominer::octo_command
  $octo_fan      = $octominer::octo_fan
  $octo_status   = $octominer::octo_status
  $octo_lcd      = $octominer::octo_lcd
  $user          = $octominer::user

  # setup udev rules
  $udev_octo = '/etc/udev/rules.d/90-octominer.rules'
  file { $udev_octo:
    ensure  => file,
    content => 'SUBSYSTEM=="usb",  DRIVERS=="usb", ATTRS{serial}=="0000:00:1a.0" , MODE="0777"',
  }

  exec { 'reload_octo_udev':
    command   => '/usr/bin/udevadm control --reload-rules && udevadm trigger',
    subscribe => File[$udev_octo],
  }

  file { $root_dir :
    ensure  => directory,
    require => Exec['reload_octo_udev'],
  }

  file { $octo_command :
    ensure  => file,
    mode    => '0755',
    source  => 'puppet:///modules/octominer/fan_controller_cli',
    require => File[$root_dir],
  }

  file { $octo_fan :
    ensure  => file,
    mode    => '0755',
    content => epp('octominer/octo-fan.bash.epp', {
        octo_command  => $octo_command,
    }),
    require => File[$root_dir],
  }

  file { $octo_status :
    ensure  => file,
    mode    => '0755',
    content => epp('octominer/octo-status.bash.epp', {
        octo_command  => $octo_command,
    }),
    require => File[$octo_fan],
  }

  file { $octo_lcd :
    ensure  => file,
    mode    => '0755',
    content => epp('octominer/octo-lcd.bash.epp', {
        octo_command        => $octo_command,
        lcd_update_interval => $octominer::lcd_update_interval,
    }),
    require => File[$octo_status],
  }

  file { $octo_ping:
    ensure  => file,
    content => epp('octominer/octo-ping.bash.epp', {
        short_timeout => $octominer::watchdog_short_timeout,
        long_timeout  => $octominer::watchdog_long_timeout,
        ping_interval => $octominer::watchdog_ping_interval,
        octo_command  => $octo_command,
    }),
    mode    => '0755',
    require => File[$octo_command,$octo_lcd],
  }

  # install the system service.
  systemd::unit_file { 'octo-ping.service':
    active  => true, # if the service should be running
    enable  => true, # if the service should be run after a reboot
    content => epp('octominer/octo.service.epp',
      {
        user        => $user,
        root_dir    => $root_dir,
        octo_run    => $octo_ping,
        description => 'Starts Octominer Ping Service'
      }
    ),
    require => File[$octo_ping],
  }
  systemd::unit_file { 'octo-lcd.service':
    active  => true,
    enable  => true,
    content => epp('octominer/octo.service.epp',
      {
        user        => $user,
        root_dir    => $root_dir,
        octo_run    => $octo_lcd,
        description => 'Runs Octominer LCD Updater Service',
      }
    ),
    require => File[$octo_lcd],
  }
}
